@@ -1,5 +1,4 @@
 import asyncio
-import fcntl
 import os
 import sys
 
@@ -27,6 +26,10 @@ class DesktopInfo:
     DESKTOP_SESSION = os.environ.get('DESKTOP_SESSION', '')
     KDE_FULL_SESSION = os.environ.get('KDE_FULL_SESSION', '')
 
+    @staticmethod
+    def dbus_supported():
+        return sys.platform not in ['win32', 'darwin', 'cygwin']
+
     @staticmethod
     def is_wayland():
         return DesktopInfo.XDG_SESSION_TYPE == 'wayland' \
@@ -36,9 +39,9 @@ class DesktopInfo:
     def desktop_environment():
         ret = DesktopInfo.OTHER
         if 'gnome' in DesktopInfo.XDG_CURRENT_DESKTOP.lower() \
-                or DesktopInfo.GNOME_DESKTOP_SESSION_ID == '':
+                or DesktopInfo.GNOME_DESKTOP_SESSION_ID != '':
             ret = DesktopInfo.GNOME
-        elif DesktopInfo.KDE_FULL_SESSION == '' \
+        elif DesktopInfo.KDE_FULL_SESSION != '' \
                 or DesktopInfo.DESKTOP_SESSION.lower() == 'kde-plasma':
             ret = DesktopInfo.KDE
         elif 'sway' in DesktopInfo.XDG_CURRENT_DESKTOP.lower():
@@ -75,6 +78,7 @@ def instance_already_running(label="default"):
     Detect if an an instance with the label is already running, globally
     at the operating system level.
     """
+    import fcntl
     lock_file_pointer = os.open(f"/tmp/fastocr_{label}.lock", os.O_WRONLY | os.O_CREAT)
 
     try:
